MessageSent

Enum MessageSent 

pub enum MessageSent {
    Yes,
    No,
}
Indication if a message was written into the provided writer.

This enum is returned by a call to step or step64 and indicates if a message was written into the provided writer. It serves as a hint to a caller to inform them that they need to ensure the message will reach the other party, be that by flushing the writer or copying the written bytes.

Note that SASL explicitly allows the option of sending an empty message. In that case a MessageSent::Yes will be returned but no bytes will have been written into the writer. How to indicate an empty message differs from protocol to protocol.

Variants



Yes

Yes a message was written and needs to be sent



No

No message needs to be sent to the other end.